@@ -1,9 +1,26 @@
 # coding: utf-8
 require 'nokogiri'
 require 'httpclient'
+require 'totoridipjp'
 
 module Plugin::PhotoSupport
   INSTAGRAM_PATTERN = %r{^https?://(?:instagr\.am|instagram\.com)/p/([a-zA-Z0-9_\-]+)}
+
+  class << self
+    # Twitter cardsのURLを画像のURLに置き換える。
+    # HTMLを頻繁にリクエストしないように、このメソッドを通すことでメモ化している。
+    # ==== Args
+    # [display_url] http://d250g2.com/
+    # ==== Return
+    # String 画像URL(http://d250g2.com/d250g2.jpg)
+    def d250g2(display_url)
+      connection = HTTPClient.new
+      page = connection.get_content(display_url)
+      unless page.empty?
+        doc = Nokogiri::HTML(page)
+        doc.css('meta[name="twitter:image:src"]').first.attribute('content') end end
+    memoize :d250g2
+  end
 end
 
 Plugin.create :photo_support do
@@ -149,30 +166,32 @@ Plugin.create :photo_support do
   end
 
   # d250g2
-  defimageopener('d250g2', %r#\Ahttp://d250g2.com/?\Z#) do
-    open('http://d250g2.com/d250g2.jpg')
+  defimageopener('d250g2', %r#\Ahttps?://(?:[\w\-]+\.)?d250g2\.com/?\Z#) do |display_url|
+    img = Plugin::PhotoSupport.d250g2(display_url)
+    open(img) if img
   end
 
   # d250g2(Twitpicが消えたとき用)
-  defimageopener('d250g2(Twitpicが消えたとき用)', %r#\Ahttp://twitpic.com/d250g2\Z#) do
+  defimageopener('d250g2(Twitpicが消えたとき用)', %r#\Ahttp://twitpic\.com/d250g2\Z#) do
     open('http://d250g2.com/d250g2.jpg')
   end
 
   # totori.dip.jp
-  defimageopener('totori.dip.jp', %r#\Ahttp://totori.dip.jp/?\Z#) do |display_url|
-    connection = HTTPClient.new
-    page = connection.get_content(display_url)
-    next nil if page.empty?
-    doc = Nokogiri::HTML(page)
-    open(doc.css('meta[property="og:image"]').first.attribute('content'))
+  defimageopener('totori.dip.jp', %r#\Ahttp://totori\.dip\.jp/?\Z#) do |display_url|
+    iwashi = Totoridipjp.イワシがいっぱいだあ…ちょっとだけもらっていこうかな
+    if iwashi.url
+      open(iwashi.url) end
   end
 
   # 600eur.gochiusa.net
   defimageopener('600eur.gochiusa.net', %r#\Ahttp://600eur\.gochiusa\.net/?\Z#) do |display_url|
-    connection = HTTPClient.new
-    page = connection.get_content(display_url)
-    next nil if page.empty?
-    doc = Nokogiri::HTML(page)
-    open(doc.css('meta[name="twitter:image:src"]').first.attribute('content'))
+    img = Plugin::PhotoSupport.d250g2(display_url)
+    open(img) if img
+  end
+
+  # yfrog
+  defimageopener('yfrog', %r#\Ahttps?://yfrog\.com/es3bcstj\Z#) do
+    img = Plugin::PhotoSupport.d250g2('http://router-cake.d250g2.com/')
+    open(img) if img
   end
 end
